DynamicGradientBackground constructor
Creates a DynamicGradientBackground widget.
The child is the widget that will be displayed on top of the dynamic background.
Implementation
const DynamicGradientBackground({super.key, required this.child});
Creates a DynamicGradientBackground widget.
The child is the widget that will be displayed on top of the dynamic background.
const DynamicGradientBackground({super.key, required this.child});